otcextensions.sdk.apig.v2.tag
=============================

.. automodule:: otcextensions.sdk.apig.v2.tag

The Tag Class
-------------

The ``Tag`` class inherits from
:class:`~otcextensions.sdk.sdk_resource.Resource`.

.. autoclass:: otcextensions.sdk.apig.v2.tag.Tag
   :members:
